### R code from vignette source 'CNVassoc_vignette.Rnw'

###################################################
### code chunk number 1: CNVassoc_vignette.Rnw:62-63
###################################################
library(CNVassoc)


###################################################
### code chunk number 2: CNVassoc_vignette.Rnw:67-68
###################################################
library(xtable)


###################################################
### code chunk number 3: CNVassoc_vignette.Rnw:90-92
###################################################
data(dataMLPA)
head(dataMLPA)


###################################################
### code chunk number 4: CNVassoc_vignette.Rnw:109-115
###################################################
par(mfrow=c(2,2),mar=c(3,4,3,1))
hist(dataMLPA$Gene1,main="Gene 1 signal histogram",xlab="",ylab="frequency")
hist(dataMLPA$Gene2,main="Gene 2 signal histogram",xlab="",ylab="frequency")
par(xaxs="i")
plot(density(dataMLPA$Gene1),main="Gene 1 signal density function",xlab="",ylab="density")
plot(density(dataMLPA$Gene2),main="Gene 2 signal density function",xlab="",ylab="density")


###################################################
### code chunk number 5: CNVassoc_vignette.Rnw:124-125
###################################################
plotSignal(dataMLPA$Gene2,case.control=dataMLPA$casco)


###################################################
### code chunk number 6: CNVassoc_vignette.Rnw:130-131
###################################################
plotSignal(dataMLPA$Gene2,case.control=dataMLPA$casco)


###################################################
### code chunk number 7: CNVassoc_vignette.Rnw:139-140
###################################################
plotSignal(dataMLPA$Gene2,case.control=dataMLPA$quanti)


###################################################
### code chunk number 8: CNVassoc_vignette.Rnw:146-147
###################################################
plotSignal(dataMLPA$Gene2,case.control=dataMLPA$quanti)


###################################################
### code chunk number 9: CNVassoc_vignette.Rnw:184-185
###################################################
cutpoints <- c(0.08470221, 0.40485249)


###################################################
### code chunk number 10: CNVassoc_vignette.Rnw:187-188
###################################################
cutpoints


###################################################
### code chunk number 11: CNVassoc_vignette.Rnw:222-223
###################################################
CNV.1<-cnv(x=dataMLPA$Gene1, threshold.0=0.06, num.class=3, mix.method = "mixdist")


###################################################
### code chunk number 12: CNVassoc_vignette.Rnw:238-239
###################################################
CNV.2<-cnv(x=dataMLPA$Gene2, threshold.0=0.01, mix.method = "mixdist")


###################################################
### code chunk number 13: CNVassoc_vignette.Rnw:261-262
###################################################
probs.2<-getProbs(CNV.2)


###################################################
### code chunk number 14: CNVassoc_vignette.Rnw:271-272
###################################################
CNV.2probs<-cnv(probs.2)


###################################################
### code chunk number 15: CNVassoc_vignette.Rnw:282-283
###################################################
CNV.2th<-cnv(x=dataMLPA$Gene2, cutoffs=cutpoints)


###################################################
### code chunk number 16: CNVassoc_vignette.Rnw:296-297
###################################################
CNV.1


###################################################
### code chunk number 17: CNVassoc_vignette.Rnw:304-305
###################################################
CNV.2


###################################################
### code chunk number 18: CNVassoc_vignette.Rnw:312-313
###################################################
CNV.2probs


###################################################
### code chunk number 19: CNVassoc_vignette.Rnw:320-326
###################################################
pdf("./figures/fig2a.pdf")
plot(CNV.1, case.control=dataMLPA$casco, main="Gene 1")
dev.off()
pdf("./figures/fig2b.pdf")
plot(CNV.2, case.control=dataMLPA$casco, main="Gene 2")
dev.off()


###################################################
### code chunk number 20: CNVassoc_vignette.Rnw:359-360
###################################################
plot(CNV.2probs, case.control=dataMLPA$casco)


###################################################
### code chunk number 21: CNVassoc_vignette.Rnw:386-388
###################################################
CNVassoc::getQualityScore(CNV.1,type="class")
CNVassoc::getQualityScore(CNV.2,type="class")


###################################################
### code chunk number 22: CNVassoc_vignette.Rnw:395-397
###################################################
CNVassoc::getQualityScore(CNV.1,type="CNVtools")
CNVassoc::getQualityScore(CNV.2,type="CNVtools")


###################################################
### code chunk number 23: CNVassoc_vignette.Rnw:404-406
###################################################
CNVassoc::getQualityScore(CNV.1,type="CANARY")
CNVassoc::getQualityScore(CNV.2,type="CANARY")


###################################################
### code chunk number 24: CNVassoc_vignette.Rnw:443-445
###################################################
model1mul<-CNVassoc(casco~CNV.1,data=dataMLPA,model="mul")
model2mul<-CNVassoc(casco~CNV.2,data=dataMLPA,model="mul")


###################################################
### code chunk number 25: CNVassoc_vignette.Rnw:456-457
###################################################
model1mul


###################################################
### code chunk number 26: CNVassoc_vignette.Rnw:463-464
###################################################
model2mul


###################################################
### code chunk number 27: CNVassoc_vignette.Rnw:479-480
###################################################
summary(model1mul)


###################################################
### code chunk number 28: CNVassoc_vignette.Rnw:487-488
###################################################
summary(model2mul)


###################################################
### code chunk number 29: CNVassoc_vignette.Rnw:500-502
###################################################
mod<-CNVassoc(quanti ~ CNV.2 + cov, family = "gaussian", data = dataMLPA, model = 'add', emsteps=10)
mod


###################################################
### code chunk number 30: CNVassoc_vignette.Rnw:512-513
###################################################
summary(mod)


###################################################
### code chunk number 31: CNVassoc_vignette.Rnw:530-532
###################################################
CNVtest(model1mul,type="Wald")
CNVtest(model1mul,type="LRT")


###################################################
### code chunk number 32: CNVassoc_vignette.Rnw:539-541
###################################################
CNVtest(model2mul,type="Wald")
CNVtest(model2mul,type="LRT")


###################################################
### code chunk number 33: CNVassoc_vignette.Rnw:553-554
###################################################
coef(summary(model1mul,ref=2))


###################################################
### code chunk number 34: CNVassoc_vignette.Rnw:563-565
###################################################
model2add<-CNVassoc(casco~CNV.2, data=dataMLPA, model="add")
model2add


###################################################
### code chunk number 35: CNVassoc_vignette.Rnw:575-576
###################################################
summary(model2add)


###################################################
### code chunk number 36: CNVassoc_vignette.Rnw:589-590
###################################################
anova(model2mul,model2add)


###################################################
### code chunk number 37: CNVassoc_vignette.Rnw:637-640
###################################################
data(NeveData)
intensities<-NeveData$data
pheno<-NeveData$pheno


###################################################
### code chunk number 38: CNVassoc_vignette.Rnw:679-680
###################################################
data(NeveCalled)


###################################################
### code chunk number 39: CNVassoc_vignette.Rnw:689-690
###################################################
probs<-getProbs(NeveCalled)


###################################################
### code chunk number 40: CNVassoc_vignette.Rnw:697-698
###################################################
probs[1:5,1:7]


###################################################
### code chunk number 41: CNVassoc_vignette.Rnw:720-721
###################################################
data(NeveRegions)


###################################################
### code chunk number 42: CNVassoc_vignette.Rnw:728-729
###################################################
probsRegions<-getProbsRegions(probs, NeveRegions, intensities)


###################################################
### code chunk number 43: CNVassoc_vignette.Rnw:737-739
###################################################
pvals<-multiCNVassoc(probsRegions, formula="pheno~CNV",
model="mult", num.copies=0:2, cnv.tol=0.01)


###################################################
### code chunk number 44: CNVassoc_vignette.Rnw:749-751
###################################################
pvalsBH<-getPvalBH(pvals)
head(pvalsBH)


###################################################
### code chunk number 45: CNVassoc_vignette.Rnw:758-759
###################################################
cumsum(table(cut(pvalsBH[,2],c(-Inf,1e-5,1e-4,1e-3,1e-2,0.05))))


###################################################
### code chunk number 46: CNVassoc_vignette.Rnw:778-779
###################################################
data(A112)


###################################################
### code chunk number 47: CNVassoc_vignette.Rnw:782-783
###################################################
head(A112)


###################################################
### code chunk number 48: CNVassoc_vignette.Rnw:786-787
###################################################
head(A112)


###################################################
### code chunk number 49: CNVassoc_vignette.Rnw:801-802
###################################################
library(CNVtools)


###################################################
### code chunk number 50: CNVassoc_vignette.Rnw:811-813
###################################################
raw.signal <- as.matrix(A112[, -c(1, 2)])
dimnames(raw.signal)[[1]] <- A112$subject


###################################################
### code chunk number 51: CNVassoc_vignette.Rnw:817-818
###################################################
pca.signal <- apply.pca(raw.signal)


###################################################
### code chunk number 52: CNVassoc_vignette.Rnw:823-827
###################################################
ncomp <- 3
batches <- factor(A112$cohort)
sample <- factor(A112$subject)
fit.pca <- CNVtest.binary(signal = pca.signal, sample = sample, batch = batches, ncomp = ncomp, n.H0 = 3, n.H1 = 0, model.var = "~ strata(cn)")


###################################################
### code chunk number 53: CNVassoc_vignette.Rnw:831-834
###################################################
pca.posterior <- as.matrix((fit.pca$posterior.H0)[, paste("P", seq(1:ncomp), sep = "")])
dimnames(pca.posterior)[[1]] <- (fit.pca$posterior.H0)$subject
ldf.signal <- apply.ldf(raw.signal, pca.posterior)


###################################################
### code chunk number 54: CNVassoc_vignette.Rnw:847-849
###################################################
CNV<-cnv(ldf.signal, batches=batches, num.class=3, mix="mclust")
CNV


###################################################
### code chunk number 55: CNVassoc_vignette.Rnw:863-864
###################################################
plot(CNV)


###################################################
### code chunk number 56: CNVassoc_vignette.Rnw:882-885
###################################################
trait <- ifelse(A112$cohort == "58C", 0, 1)
fit <- CNVassoc(trait ~ CNV, model = "add")
CNVtest(fit,"LRT")


###################################################
### code chunk number 57: CNVassoc_vignette.Rnw:888-891
###################################################
# by default CNVtest.binary assumes: model.var = "~ strata(batch, cn)", model.disease = "~ cn" (trend CNV effect, and different vars per batch).
fit.cnvtools <- CNVtest.binary(signal=ldf.signal,sample=sample,batch=batches,disease.status=trait,ncomp=ncomp,n.H0=3,n.H1=1,model.var="~cn")
chi.cnvtools  <-  -2*(fit.cnvtools$model.H0$lnL-fit.cnvtools$model.H1$lnL)


###################################################
### code chunk number 58: CNVassoc_vignette.Rnw:898-900
###################################################
fit <- CNVassoc(trait ~ CNV)
CNVtest(fit,"LRT")


###################################################
### code chunk number 59: CNVassoc_vignette.Rnw:903-905
###################################################
fit.cnvtools <- CNVtest.binary(signal=ldf.signal,sample=sample,batch=batches,disease.status=trait,ncomp=3,n.H0=3,n.H1=1,model.disease="~as.factor(cn)")
chi.cnvtools  <-  -2*(fit.cnvtools$model.H0$lnL-fit.cnvtools$model.H1$lnL)


###################################################
### code chunk number 60: CNVassoc_vignette.Rnw:1006-1009
###################################################
data(SNPTEST)
dim(cases)
dim(controls)


###################################################
### code chunk number 61: CNVassoc_vignette.Rnw:1013-1014
###################################################
cases[1:10,1:11]


###################################################
### code chunk number 62: CNVassoc_vignette.Rnw:1017-1018
###################################################
cases[1:10,1:11]


###################################################
### code chunk number 63: CNVassoc_vignette.Rnw:1022-1023
###################################################
controls[1:10,1:11]


###################################################
### code chunk number 64: CNVassoc_vignette.Rnw:1026-1027
###################################################
controls[1:10,1:11]


###################################################
### code chunk number 65: CNVassoc_vignette.Rnw:1055-1061
###################################################
nSNP<-nrow(cases)
probs<-lapply(1:nSNP, function(i) {
  snpi.cases<-matrix(as.double(cases[i,6:ncol(cases)]),ncol=3,byrow=TRUE)
  snpi.controls<-matrix(as.double(controls[i,6:ncol(controls)]),ncol=3,byrow=TRUE)
  return(rbind(snpi.cases,snpi.controls))
})


###################################################
### code chunk number 66: CNVassoc_vignette.Rnw:1070-1071
###################################################
casecon<-rep(1:0,c(500,500))


###################################################
### code chunk number 67: CNVassoc_vignette.Rnw:1076-1077
###################################################
pvals<-multiCNVassoc(probs, formula="casecon~CNV",model="add", num.copies=0:2, cnv.tol=0.001)


###################################################
### code chunk number 68: CNVassoc_vignette.Rnw:1081-1083
###################################################
pvalsBH<-getPvalBH(pvals)
head(pvalsBH)


###################################################
### code chunk number 69: CNVassoc_vignette.Rnw:1087-1088
###################################################
table(cut(pvalsBH[,2],c(-Inf,1e-3,1e-2,0.05,0.1,Inf)))


###################################################
### code chunk number 70: CNVassoc_vignette.Rnw:1125-1131
###################################################
set.seed(123456)
rr<-1.7
incid0<-0.12
lambda<-c(incid0,incid0*rr,incid0*rr^2)
dsim<-simCNVdataPois(n=4000,mu.surrog=0:2,sd.surrog=rep(0.4,3),w=c(0.25,0.5,0.25),lambda=lambda)
head(dsim)


###################################################
### code chunk number 71: CNVassoc_vignette.Rnw:1143-1145
###################################################
CNV<-cnv(dsim$surrog,mix="mclust")
CNV


###################################################
### code chunk number 72: CNVassoc_vignette.Rnw:1150-1152
###################################################
fit<-CNVassoc(resp~CNV, data=dsim, family="poisson", model="add")
coef(summary(fit))


###################################################
### code chunk number 73: CNVassoc_vignette.Rnw:1159-1163
###################################################
fit.gold<-glm(resp~cnv, data=dsim, family="poisson")
table.gold<-c(exp(c(coef(fit.gold)[2],confint(fit.gold)[2,])),coef(summary(fit.gold))[2,4])
names(table.gold)<-c("RR","lower","upper","p-value")
table.gold


###################################################
### code chunk number 74: CNVassoc_vignette.Rnw:1173-1177
###################################################
fit.naive<-glm(resp~CNV, data=dsim, family="poisson")
table.naive<-c(exp(c(coef(fit.naive)[2],confint(fit.naive)[2,])),coef(summary(fit.naive))[2,4])
names(table.naive)<-c("RR","lower","upper","p-value")
table.naive


###################################################
### code chunk number 75: CNVassoc_vignette.Rnw:1181-1187
###################################################
taula<-rbind(
table.gold[1:3],
coef(summary(fit))[,c("RR","lower.lim","upper.lim")],
table.naive[1:3])
rownames(taula)<-c("Gold","LC","Naive")
xtable(taula,"Comparison of RR estimated by the gold standard model, a latent class model (LC) and naive approach",label="table-compare")


###################################################
### code chunk number 76: CNVassoc_vignette.Rnw:1223-1237
###################################################
set.seed(123456)
n<-5000
w<-c(0.25,0.5,0.25)
mu.surrog<-0:2
sd.surrog<-rep(0.4,3)
hr<-1.5
incid0<-0.05
lambda<-c(incid0,incid0*hr,incid0*hr^2)
shape<-1
scale <-lambda^(-1/shape)
perc.obs<-0.10
time.cens<-qweibull(perc.obs,mean(shape),mean(scale))
dsim<-simCNVdataWeibull(n, mu.surrog, sd.surrog, w, lambda, shape, time.cens)
head(dsim)


###################################################
### code chunk number 77: CNVassoc_vignette.Rnw:1251-1253
###################################################
CNV<-cnv(dsim$surrog,mix="mclust")
CNV


###################################################
### code chunk number 78: CNVassoc_vignette.Rnw:1260-1262
###################################################
fit<-CNVassoc(Surv(resp,cens)~CNV, data=dsim, family="weibull", model="add")
coef(summary(fit))


